@@ -10,6 +10,10 @@
 //
 //
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <iostream>
 #include <boost/regex.hpp>
 
