@@ -6,6 +6,10 @@
  *  Copyright: See COPYING file that comes with this distribution
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "stylefileparser.h"
 #include "parsestyles.h"
 #include "settings.h"
