@@ -52,7 +52,9 @@ int main() {
     check_range_regex("simple regex");
     check_range_regex("[[:alpha:]]+");
     // test with a wrong regular expression
-    check_range_regex("{notclosed", false);
+    // this is accepted now
+    // https://savannah.gnu.org/bugs/index.php?41786
+    check_range_regex("{notclosed");
 
     // reset regular expressions
     ranges.clear();
